@@ -52,7 +52,7 @@ sub install {
         doit ("find", $mpath, "-name", "*-tst", "-exec", "rm", "-f", "{}", ";");
 
 	# Remove empty left-over directories
-	doit ("rmdir", "--ignore-fail-on-non-empty", "-p", $mpath);
+	doit ("find", $mpath, "-type", "d", "-empty", "-delete");
 
     }
 
